package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.cryptopro.CryptoProObjectIdentifiers;
import cn.com.infosec.asn1.cryptopro.GOST3410PublicKeyAlgParameters;
import cn.com.infosec.asn1.pkcs.PrivateKeyInfo;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.crypto.params.GOST3410PrivateKeyParameters;
import cn.com.infosec.jce.interfaces.GOST3410Params;
import cn.com.infosec.jce.interfaces.GOST3410PrivateKey;
import cn.com.infosec.jce.interfaces.PKCS12BagAttributeCarrier;
import cn.com.infosec.jce.spec.GOST3410ParameterSpec;
import cn.com.infosec.jce.spec.GOST3410PrivateKeySpec;
import cn.com.infosec.jce.spec.GOST3410PublicKeyParameterSetSpec;
import java.math.BigInteger;
import java.util.Enumeration;

public class JDKGOST3410PrivateKey implements GOST3410PrivateKey, PKCS12BagAttributeCarrier {
   BigInteger x;
   GOST3410Params gost3410Spec;
   private PKCS12BagAttributeCarrier attrCarrier;

   protected JDKGOST3410PrivateKey() {
      JDKGOST3410PrivateKey var10000 = this;
      super();
      PKCS12BagAttributeCarrierImpl var1;
      var1 = new PKCS12BagAttributeCarrierImpl.<init>();
      var10000.attrCarrier = var1;
   }

   JDKGOST3410PrivateKey(GOST3410PrivateKey key) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = key.getX();
      this.gost3410Spec = key.getParameters();
   }

   JDKGOST3410PrivateKey(GOST3410PrivateKeySpec spec) {
      JDKGOST3410PrivateKey var10000 = this;
      super();
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = spec.getX();
      GOST3410PrivateKeySpec var10005 = spec;
      BigInteger var3 = spec.getP();
      BigInteger spec1 = spec.getQ();
      BigInteger var2 = var10005.getA();
      var10000.gost3410Spec = new GOST3410ParameterSpec(new GOST3410PublicKeyParameterSetSpec(var3, spec1, var2));
   }

   JDKGOST3410PrivateKey(PrivateKeyInfo info) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      GOST3410PublicKeyAlgParameters var2;
      var2 = new GOST3410PublicKeyAlgParameters.<init>((ASN1Sequence)info.getAlgorithmId().getParameters());
      byte[] info1;
      byte[] var3 = new byte[(info1 = ((DEROctetString)info.getPrivateKey()).getOctets()).length];

      for(int var4 = 0; var4 != info1.length; ++var4) {
         var3[var4] = info1[info1.length - 1 - var4];
      }

      this.x = new BigInteger(1, var3);
      this.gost3410Spec = GOST3410ParameterSpec.fromPublicKeyAlg(var2);
   }

   JDKGOST3410PrivateKey(GOST3410PrivateKeyParameters params, GOST3410ParameterSpec spec) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = params.getX();
      this.gost3410Spec = spec;
      if (spec == null) {
         throw new IllegalArgumentException("spec is null");
      }
   }

   public String getAlgorithm() {
      return "GOST3410";
   }

   public String getFormat() {
      return "PKCS#8";
   }

   public byte[] getEncoded() {
      byte[] var1;
      byte[] var2;
      if ((var1 = this.getX().toByteArray())[0] == 0) {
         var2 = new byte[var1.length - 1];
      } else {
         var2 = new byte[var1.length];
      }

      for(int var3 = 0; var3 != var2.length; ++var3) {
         var2[var3] = var1[var1.length - 1 - var3];
      }

      GOST3410Params var5;
      PrivateKeyInfo var6;
      if ((var5 = this.gost3410Spec) instanceof GOST3410ParameterSpec) {
         var6 = new PrivateKeyInfo.<init>(new AlgorithmIdentifier(CryptoProObjectIdentifiers.gostR3410_94, (new GOST3410PublicKeyAlgParameters(new DERObjectIdentifier(var5.getPublicKeyParamSetOID()), new DERObjectIdentifier(this.gost3410Spec.getDigestParamSetOID()))).getDERObject()), new DEROctetString(var2));
      } else {
         PrivateKeyInfo var10000 = var6 = new PrivateKeyInfo;
         AlgorithmIdentifier var10001 = new AlgorithmIdentifier(CryptoProObjectIdentifiers.gostR3410_94);
         DEROctetString var4;
         var4 = new DEROctetString.<init>(var2);
         var10000.<init>(var10001, var4);
      }

      return var6.getDEREncoded();
   }

   public GOST3410Params getParameters() {
      return this.gost3410Spec;
   }

   public BigInteger getX() {
      return this.x;
   }

   public void setBagAttribute(DERObjectIdentifier oid, DEREncodable attribute) {
      this.attrCarrier.setBagAttribute(oid, attribute);
   }

   public DEREncodable getBagAttribute(DERObjectIdentifier oid) {
      return this.attrCarrier.getBagAttribute(oid);
   }

   public Enumeration getBagAttributeKeys() {
      return this.attrCarrier.getBagAttributeKeys();
   }
}
